sqltriples.Query.Subject

Package sqltriples :: Module Query :: Class Subject |
[show private | hide private]
[frames | no frames]

## Class Subject

    AbstractQuery --+
                    |
                   Subject

A class representing a more conveniently accessible subject.

Method Summary
| ``__init__`(self, store, subject)` Initialise the subject instance with the given 'store' and 'subject' identifier.
| `__delitem__(self, predicate)`
| `__getitem__(self, predicate)`
| `__setitem__(self, predicate, object)`
| `get_child_query(self, index)`
| `get_query(self, index, constraints)`
| `get_subquery(self, parent_columns, parent_index, index, match_first, match_parent, match_child)`
| `keys(self)`
| `values(self)`
Inherited from AbstractQuery
| ``_get_exposed_columns`(self)`

Class Variable Summary
`list` | `exposed_columns` = `[('subject', 'subject_type')]`
Inherited from AbstractQuery
`list` | `table_columns` = `[('subject', 'subject_type', 0), ('predi...`

Method Details

### __init__(self, store, subject) (Constructor) Initialise the subject instance with the given 'store' and 'subject' identifier.

Class Variable Details

    ### exposed_columns Type: `list` Value:
        [('subject', 'subject_type')]

Generated by Epydoc 2.1 on Sat Sep 30 00:54:36 2006 | http://epydoc.sf.net